@@ -434,6 +434,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.resolution.addItem(str(x))
 		for x in diatonic.basic_keys:
 			self.ui.key.addItem(x)
+		for x in ['default', 'alsa', 'oss', 'jack', 'portaudio', 'coreaudio', 'sndmgr', 'Direct Sound']:
+			self.ui.driver.addItem(x)
+				
 
 	def connect_widgets(self):
 		self.connect(self.ui.startbutton, 
@@ -668,6 +671,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i != -1:
 			self.ui.key.setCurrentIndex(i)
 
+		i = 0
+		if hasattr(o, 'driver'):
+			i = combo_index_by_text(self.ui.driver, o.driver)
+		self.ui.driver.setCurrentIndex(i)
+
+
 		# CheckBoxes
 		self.ui.swing.setChecked(bool(o.swing))
 		self.ui.no_fluidsynth.setChecked(bool(o.no_fluidsynth))
@@ -703,6 +712,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# ComboBoxes
 		o.resolution = int(str(self.ui.resolution.currentText()))
 		o.key = str(self.ui.key.currentText())
+		o.driver = str(self.ui.driver.currentText())
+		if o.driver == 'default':
+			o.driver = None
 
 		# SpinBoxes
 		o.bpm = int(self.ui.bpm.value())
